package sun.awt;

import java.util.StringTokenizer;
import java.awt.Toolkit;
import java.awt.AWTEvent;
import java.awt.EventQueue;

public class TracedEventQueue extends EventQueue
{
    static boolean trace;
    static int[] suppressedIDs;
    
    public TracedEventQueue() {
    }
    
    @Override
    public void postEvent(AWTEvent awtEvent) {
        boolean n = true;
        int id = awtEvent.getID();
        int i = 0;
        while (i < TracedEventQueue.suppressedIDs.length) {
            if (id == TracedEventQueue.suppressedIDs[i]) {
                n = false;
                break;
            }
            ++i;
        }
        if (!(n == 0)) {
            System.out.println(Thread.currentThread().getName() + ": " + awtEvent);
        }
        super.postEvent(awtEvent);
    }
    
    static {
        TracedEventQueue.trace = false;
        TracedEventQueue.suppressedIDs = null;
        String property = Toolkit.getProperty("AWT.IgnoreEventIDs", "");
        if (property.length() > 0) {
            StringTokenizer stringTokenizer = new StringTokenizer(property, ",");
            int countTokens = stringTokenizer.countTokens();
            TracedEventQueue.suppressedIDs = new int[countTokens];
            for (int i = 0; i < countTokens; ++i) {
                String nextToken = stringTokenizer.nextToken();
                try {
                    TracedEventQueue.suppressedIDs[i] = Integer.parseInt(nextToken);
                }
                catch (NumberFormatException ex) {
                    System.err.println("Bad ID listed in AWT.IgnoreEventIDs in awt.properties: \"" + nextToken + "\" -- skipped");
                    TracedEventQueue.suppressedIDs[i] = 0;
                }
            }
        }
        else {
            TracedEventQueue.suppressedIDs = new int[0];
        }
    }
}
